<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 6/3/2009
// Revised: 1/12/2/12	ELL
// Added saving to page_data_draft table to accomodate new upgrade for save to draft mode.
// Revised: 1/16/2012	ELL
// Added seed HTML to make it easier to start editing the page.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 6/24/2013	ELL
// Added ability to specify meaningful names.
	
	include ("check_session.php");
		
	$area_type = $_REQUEST['area_type'];
	$suffix = $_REQUEST['suffix'];
	if (is_numeric($suffix))
		$special_page_name = $area_type . $suffix;
	else
		$special_page_name = $area_type . "_" . $suffix;
	
	$body_html = "\n<p>Enter your content here.</p>\n";
	$today = date("Y-m-d H:i:s");
	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_special SET page_name='" . $special_page_name . "', page_content='" . $body_html . "', revised='" . $today . "'";
	$cnt = $bwb_dbh->exec($query);
	// Copy page data to draft table.
	$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='" . $special_page_name . "', page_content='" . $body_html . "', revised='" . $today . "', `source`=1";
	$cnt = $bwb_dbh->exec($query);
	
	header("Location: manage_special.php");
?>